<h1 align="center">
  <br>
  <a href="https://i.imgur.com/tTOJC3x.png"><img src="https://i.imgur.com/tTOJC3x.png" alt="RESPY" width="300"></a>
</h1>
<h4 align="center">Fundamental Formulas for Remote Sensing and Sensing Geometry Management</h4>

<p align="center">
  <a href="http://forthebadge.com">
    <img src="http://forthebadge.com/images/badges/made-with-python.svg"
         alt="Gitter">
  </a>
  <a href="http://forthebadge.com"><img src="http://forthebadge.com/images/badges/built-with-love.svg"></a>
  <a href="http://forthebadge.com">
      <img src="http://forthebadge.com/images/badges/built-with-science.svg">
  </a>
</p>


<p align="center">
  <a href="#description">Description</a> •
  <a href="#installation">Installation</a> •
  <a href="#example">Example</a> •
    <a href="#documentation">Doumentation</a> •
  <a href="#authors">Author</a> •
  <a href="#acknowledgments">Acknowledgments</a>
</p>

<p align="center">
  <a href="https://travis-ci.com/ibaris/rspy"><img src="https://travis-ci.com/ibaris/rspy.svg?token=sdE5XxL3JmzxUdz7gza1&branch=master"></a>
  <a href='https://coveralls.io/github/ibaris/rspy?branch=bin_units'><img src='https://coveralls.io/repos/github/ibaris/rspy/badge.svg?branch=bin_units' alt='Coverage Status' /></a>
  <a href="https://www.codefactor.io/repository/github/ibaris/rspy"><img src="https://www.codefactor.io/repository/github/ibaris/rspy/badge" alt="CodeFactor" /></a>
</p>

# Description


# Installation

### Standard Python

  
### Test installation success

# Example


# Documentation

# Built With
* Python 2.7 (But it works with Python 3.5 as well)
* Requirements: numpy, sympy

# Authors
* **Ismail Baris** - *Initial work* - (i.baris@outlook.de)

## Acknowledgments
*  <a href="https://www.researchgate.net/profile/Thomas_Jagdhuber">Thomas Jagdhuber </a>

---

> ResearchGate [@Ismail_Baris](https://www.researchgate.net/profile/Ismail_Baris) &nbsp;&middot;&nbsp;
> GitHub [@ibaris](https://github.com/ibaris) &nbsp;&middot;&nbsp;
> Instagram [@ism.baris](https://www.instagram.com/ism.baris/) &nbsp;&middot;&nbsp;
> Code:Stats [@ibaris](https://codestats.net/users/ibaris)
